climpred.classes.PerfectModelEnsemble.compute\_persistence
==========================================================

.. currentmodule:: climpred.classes

.. automethod:: PerfectModelEnsemble.compute_persistence
